import { aws_ec2 as ec2, aws_eks as eks, aws_iam as iam, aws_route53 as r53 } from 'aws-cdk-lib';
import { Construct } from 'constructs';
import { NodeTaint } from '../types/cluster';
import * as ema from './eks-managed-addon';
export { VpcCniAddonVersion } from './eks-managed-addon';
/**
 * Constructor properties for SuperEks.
 * Get merged with `defaultSuperEksProps`.
 */
export interface SuperEksProps {
    /**
     * Wrapper for all cluster props>
     */
    readonly clusterProps?: eks.ClusterProps;
    /**
     * Additional Roles that should be granted cluster admin privileges.
     * Can also be added manually after cluster creation by using `cluster.awsAuth.addMastersRole(role)`.
     */
    readonly adminRoles?: iam.IRole[];
    /**
     * A hosted zone for DNS management. Records in this zone will be created for your workloads by 'external-dns'.
     */
    readonly hostedZone: r53.IHostedZone;
    /**
     * Config for the Nodegroup created to host SuperEks specific workloads.
     * If you override the `launchTemplateSpec` you're responsible for adding the necessary userdata to taint the nodes,
     * see `../config/cluster#nodeTaintUserdata`
     */
    readonly superEksNodegroupProps?: eks.NodegroupOptions;
    /**
     * Specific properties for EKS managed add-ons
     */
    readonly addonProps?: AddonProps;
}
/**
 * Specific properties for EKS managed add-ons
 */
export interface AddonProps {
    readonly vpcCniAddonVersion?: ema.VpcCniAddonVersion;
}
/**
 * Default config for SuperEks
 */
export declare const defaultSuperEksProps: {
    clusterProps: {
        version: eks.KubernetesVersion;
    };
    superEksNodegroupProps: {
        nodegroupName: string;
        labels: {
            workload: string;
        };
        instanceTypes: ec2.InstanceType[];
    };
};
/**
 * SuperEks wraps eks.Cluster to include batteries
 */
export declare class SuperEks extends Construct {
    private props;
    /**
     * The created cluster.
     *
     * @attribute
     */
    readonly cluster: eks.Cluster;
    /**
     * `eks.Nodegroup`s added to the cluster
     * @attribute
     *
     * @default An internal `eks.Nodegroup` will be created for super-eks related workloads
     */
    readonly additionalNodegroups: eks.Nodegroup[];
    constructor(scope: Construct, id: string, props: SuperEksProps);
    /**
     * Generates `ec2.MultipartUserData` to attach to a `eks.Nodegroup` `ec2.LaunchTemplate`
     * so that the Nodes are getting tainted with the given `NodeTaint`.
     *
     * @param taint the taint that should be applied to the Nodes.
     */
    nodeTaintUserdata(taint: NodeTaint): ec2.MultipartUserData;
    private addAdminRoles;
    private configureCluster;
    private addSuperEksNodegroup;
    private addManagedVpcCniAddon;
    private hardenNodes;
    private configureExternalDNS;
    private configureAwsLoadBalancerController;
    private configureFluentBit;
    /**
     * Adds PDBs to system workloads so that the cluster autoscaler can evict them.
     */
    private addPodDisruptionBudgets;
    private addExternalSecrets;
}
